/* A Bison parser, made by GNU Bison 3.0.4.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_YY_GRAMMAR_H_INCLUDED
# define YY_YY_GRAMMAR_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token type.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    T_SERVICE = 258,
    T_PORT = 259,
    T_EXEC = 260,
    T_PROTO = 261,
    T_UDP = 262,
    T_TCP = 263,
    T_UID = 264,
    T_GID = 265,
    T_BACKLOG = 266,
    T_INSTANCES = 267,
    T_WAIT = 268,
    T_DEFAULT = 269,
    T_NICE = 270,
    T_INTERFACE = 271,
    T_ANY = 272,
    T_FISH = 273,
    T_CHROOT = 274,
    T_SERVER = 275,
    T_DIR = 276,
    T_RPC = 277,
    T_VERSION = 278,
    T_NAME = 279,
    T_WRAP = 280,
    T_CAPS = 281,
    T_FAMILY = 282,
    T_IPV4 = 283,
    T_IPV6 = 284,
    T_INITGROUPS = 285,
    T_BANNER = 286,
    T_ECHO = 287,
    T_DISCARD = 288,
    T_FILTER = 289,
    T_CHARGEN = 290,
    T_LOOPBACK = 291,
    T_ENABLED = 292,
    T_RLIMIT = 293,
    T_LIM_CPU = 294,
    T_LIM_FSIZE = 295,
    T_LIM_DATA = 296,
    T_LIM_STACK = 297,
    T_LIM_CORE = 298,
    T_LIM_RSS = 299,
    T_LIM_NPROC = 300,
    T_LIM_NOFILE = 301,
    T_LIM_MEMLOCK = 302,
    T_LIM_INFINITY = 303,
    T_SOFT = 304,
    T_HARD = 305,
    T_YES = 306,
    T_NO = 307,
    T_LOG = 308,
    T_PIPE = 309,
    T_SYSLOG = 310,
    T_PATH = 311,
    T_MODE = 312,
    T_ACCEPT = 313,
    T_DENY = 314,
    T_CLOSE = 315,
    T_EXIT = 316,
    T_NUMERIC = 317,
    T_QSTRING = 318,
    T_IPADDR = 319
  };
#endif
/* Tokens.  */
#define T_SERVICE 258
#define T_PORT 259
#define T_EXEC 260
#define T_PROTO 261
#define T_UDP 262
#define T_TCP 263
#define T_UID 264
#define T_GID 265
#define T_BACKLOG 266
#define T_INSTANCES 267
#define T_WAIT 268
#define T_DEFAULT 269
#define T_NICE 270
#define T_INTERFACE 271
#define T_ANY 272
#define T_FISH 273
#define T_CHROOT 274
#define T_SERVER 275
#define T_DIR 276
#define T_RPC 277
#define T_VERSION 278
#define T_NAME 279
#define T_WRAP 280
#define T_CAPS 281
#define T_FAMILY 282
#define T_IPV4 283
#define T_IPV6 284
#define T_INITGROUPS 285
#define T_BANNER 286
#define T_ECHO 287
#define T_DISCARD 288
#define T_FILTER 289
#define T_CHARGEN 290
#define T_LOOPBACK 291
#define T_ENABLED 292
#define T_RLIMIT 293
#define T_LIM_CPU 294
#define T_LIM_FSIZE 295
#define T_LIM_DATA 296
#define T_LIM_STACK 297
#define T_LIM_CORE 298
#define T_LIM_RSS 299
#define T_LIM_NPROC 300
#define T_LIM_NOFILE 301
#define T_LIM_MEMLOCK 302
#define T_LIM_INFINITY 303
#define T_SOFT 304
#define T_HARD 305
#define T_YES 306
#define T_NO 307
#define T_LOG 308
#define T_PIPE 309
#define T_SYSLOG 310
#define T_PATH 311
#define T_MODE 312
#define T_ACCEPT 313
#define T_DENY 314
#define T_CLOSE 315
#define T_EXIT 316
#define T_NUMERIC 317
#define T_QSTRING 318
#define T_IPADDR 319

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED

union YYSTYPE
{
#line 107 "grammar.y" /* yacc.c:1909  */

	long num;
	char *cp;
	struct passwd *uid;
	struct group *gid;
	struct opmetalist *opml;
	struct opmeta *opm;
	rlim_t rl;

#line 192 "grammar.h" /* yacc.c:1909  */
};

typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE yylval;

int yyparse (void);

#endif /* !YY_YY_GRAMMAR_H_INCLUDED  */
